@@ -472,9 +472,7 @@ where
         let scope = &mut *scope_ref_mut;
         let mut factory_params = Vec::with_capacity(scope.imports.len() + 1);
         if has_export {
-            define_deps_arg
-                .elems
-                .push(Some(Lit::Str(quote_str!("exports")).as_arg()));
+            define_deps_arg.elems.push(Some("exports".as_arg()));
             factory_params.push(Param {
                 span: DUMMY_SP,
                 decorators: Default::default(),
@@ -557,9 +555,7 @@ where
                     None => src.clone(),
                 };
 
-                define_deps_arg
-                    .elems
-                    .push(Some(Lit::Str(quote_str!(src)).as_arg()));
+                define_deps_arg.elems.push(Some(src.as_arg()));
             }
             factory_params.push(Param {
                 span: DUMMY_SP,
