@@ -441,7 +441,7 @@ where
                                                 // export { foo as bar }
                                                 //  -> 'bar'
                                                 let i = exported.unwrap_or(orig);
-                                                Lit::Str(quote_str!(i.span, i.sym)).as_arg()
+                                                quote_str!(i.span, i.sym).as_arg()
                                             },
                                             make_descriptor(value).as_arg(),
                                         ])
